@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 16.2 Debian package creator
-# Release 2020-03-06
+# DaVinci Resolve 16.2.1 Debian package creator
+# Release 2020-04-21
 # By Daniel Tufvesson
 #
 
@@ -26,6 +26,11 @@ copy_object() {
     fi
 }
 
+link_object() {
+    echo "[LINK] $2 [TO] $1"
+    ln -s "$1" "$2"
+}
+
 create_directory() {
     if [ -e "$1" ] ; then
 	echo "[ERROR: DIRECTORY EXISTS] $1"
@@ -57,7 +62,7 @@ make_executable() {
 }
 
 # Setup variables
-RESOLVE_VERSION=16.2
+RESOLVE_VERSION=16.2.1
 DEB_STEPPING=1
 case $1 in
     studio)
@@ -143,7 +148,7 @@ SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="066
 EOF
 
 # Fix missing x flag
-chmod +x ${RESOLVE_BASE_DIR}/bin/DaVinciPanelDaemon
+#chmod +x ${RESOLVE_BASE_DIR}/bin/DaVinciPanelDaemon
 
 # Install panel API library
 create_directory ${DEB_DIR}/usr/lib/x86_64-linux-gnu
@@ -151,8 +156,8 @@ extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_
 
 # Create symlinks
 create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
-ln -s /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
-ln -s /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
+link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
+link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
 
 # Create common data dir
 create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
@@ -190,7 +195,6 @@ chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
 test ! -e /usr/lib64 && mkdir /usr/lib64 && touch /usr/lib64.by.makeresolvedeb
-test ! -h /usr/lib64/libcuda.so && ln -s /usr/lib/x86_64-linux-gnu/libcuda.so /usr/lib64/libcuda.so && touch /usr/lib64/libcuda.so.by.makeresolvedeb
 test ! -h /usr/lib64/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib64/libDaVinciPanelAPI.so
 exit 0
 EOF
@@ -198,7 +202,6 @@ make_executable ${DEB_DIR}/DEBIAN/postinst
 cat > ${DEB_DIR}/DEBIAN/postrm <<EOF
 #!/bin/sh
 test -h /usr/lib64/libDaVinciPanelAPI.so && rm /usr/lib64/libDaVinciPanelAPI.so
-test -e /usr/lib64/libcuda.so.by.makeresolvedeb && rm /usr/lib64/libcuda.so && rm /usr/lib64/libcuda.so.by.makeresolvedeb
 test -e /usr/lib64.by.makeresolvedeb && rmdir /usr/lib64 && rm /usr/lib64.by.makeresolvedeb
 exit 0
 EOF
